@@ -270,6 +270,7 @@ def main(**kwargs):
     quiet = kwargs['quiet']
     two_line_threshold = kwargs['two_line_threshold'][0]
     skip = kwargs['s']    # this one also a list
+    hist_bins = kwargs['hist_bins'][0]
 
     if not fixed == [None] and running == 0 and not two_line_test and len(fixed) > dims:
         raise RuntimeError('value of k must be less than or equal to number of fixed (-f) dimensions.')
@@ -294,18 +295,23 @@ def main(**kwargs):
     if two_line_test:
         try:
             settings = pickle.load(open('settings.pkl', 'rb'))
-            print('Loaded settings.pkl...')
+            if not quiet:
+                print('Loaded settings.pkl...')
             try:
                 information_error_override = settings.information_error_override
-                print('Setting information_error_override = ' + str(information_error_override))
+                if not quiet:
+                    print('Setting information_error_override = ' + str(information_error_override))
             except AttributeError:
                 information_error_override = False
-                print('information_error_override is not set; defaulting to False')
+                if not quiet:
+                    print('information_error_override is not set; defaulting to False')
             try:
                 information_error_max_dims = settings.information_error_max_dims
-                print('Setting maximum number of two_line_test dimensions to: ' + str(int(information_error_max_dims)))
+                if not quiet:
+                    print('Setting maximum number of two_line_test dimensions to: ' + str(int(information_error_max_dims)))
             except AttributeError:
-                print('information_error_max_dims is not set; defaulting to no limit')
+                if not quiet:
+                    print('information_error_max_dims is not set; defaulting to no limit')
         except FileNotFoundError:
             pass
 
@@ -333,7 +339,7 @@ def main(**kwargs):
                                ' you sure it includes rate-of-change data?')
         num_cvs = int(num_cvs / 2)
 
-    if two_line_test:
+    if two_line_test and not quiet:
         print('Two line test requires at least five optimizations, so there will be five progress bars before testing.')
 
     # Prepare for and then enter optimization loop
@@ -502,7 +508,7 @@ def main(**kwargs):
         B_results = []
         for obs in current_best[3]:  # iterate over B observations
             B_results.append(eval_rc(current_best[0].x, obs))
-        hist_result = numpy.histogram(A_results + B_results, 10)  # this step just to bin, not the final histogram
+        hist_result = numpy.histogram(A_results + B_results, hist_bins)  # this step just to bin, not the final histogram
         rc_values = []      # initialize results list
         probs = []          # initialize results list
         for bin_index in range(len(hist_result[0])):
@@ -519,9 +525,10 @@ def main(**kwargs):
             else:
                 raise RuntimeError('attempted to build sigmoid plot, but one or more histogram bins is empty. This '
                                    'may indicate insufficient data in the input file. All other results from this call '
-                                   'to lmax.py have been written, but proceed with caution. This error can also occur '
-                                   'when one or more of the CVs making up the final RC takes on discrete values instead'
-                                   ' of continuous ones.')
+                                   'to lmax.py have been written, but proceed with caution, and consider trying again '
+                                   'with a smaller value given for --hist_bins (the default is 10). This error can also'
+                                   ' occur when one or more of the CVs making up the final RC takes on discrete values '
+                                   'instead of continuous ones.')
             rc_values.append(numpy.mean([hist_result[1][bin_index + 1], hist_result[1][bin_index]]))
             probs.append(count_ratio)
 
@@ -555,10 +562,10 @@ if __name__ == "__main__":
     parser.add_argument('-q', metavar='include_qdot', type=str, nargs=1, default=['present'],
                         help='valid options are: "present", "absent", and "ignore" (quotes excluded). If "present" or '
                              '"ignore", the input file is assumed to include rate-of-change ("q") data for each CV '
-                             '(formatted as in e.g., "A <- CV0 CV1 q0 q1"); in the former case, a q term will be '
-                             'included in the RC for each CV, implementing inertial likelihood maximization. In the '
-                             'latter, no such terms will be included. Finally, if "absent", the q data will be assumed '
-                             'not to be present in the input file. Default=present')
+                             '(formatted as in e.g., "A <- CV0 CV1 q0 q1"); in the former case, q terms will be used to'
+                             'select the RC (but will not appear in the final RC), implementing inertial likelihood '
+                             'maximization. In the latter, rate of change terms are not used. Finally, if "absent", the'
+                             ' q data will be assumed not to be present in the input file at all. Default=present')
     parser.add_argument('-r', metavar='running', type=int, nargs=1, default=[0],
                         help='if > 0, runs from k = 1 to "running" using the previously obtained k - 1 results as the '
                              'argument for f, ignoring the arguments passed for k and f. Default=0')
@@ -569,16 +576,21 @@ if __name__ == "__main__":
                         help='If this option is given, progress messages outputted to the terminal are suppressed and ' 
                              'only the final result is written (either to the terminal or the output file.)')
     parser.add_argument('--two_line_test', action='store_true', default=False,
-                        help='If this option is given, arguments passed for k, f, and r are ignored, and the best RC is'
-                             ' determined based on the two-line method (see documentation).')
+                        help='If this option is given, arguments passed for k, f, and r are ignored, and the RC is '
+                             'chosen based on the two-line method (see documentation).')
     parser.add_argument('--plots', action='store_true', default=False,
                         help='If True, plots the final fit between the model and data committor sigmoid. '
-                             'If this option is given alongside two_line_test, gnuplot will be used to write plots to the '
-                             'terminal during evaluations of the two_line_test termination criterion (if it is installed). '
-                             'The sigmoid data is also printed to the terminal.')
+                             'If this option is given alongside two_line_test, gnuplot will be used to write plots to '
+                             'the terminal during evaluations of the two_line_test termination criterion (if it is '
+                             'installed). The sigmoid data is also printed to the terminal or output file.')
     parser.add_argument('--two_line_threshold', metavar='two_line_threshold', type=float, nargs=1, default=[0.5],
                         help='If this option is given alongside two_line_test, sets the maximum ratio of slopes in the'
                              'two-line test. See the documentation for two_line_test for details. Default=0.5')
+    parser.add_argument('--hist_bins', metavar='hist_bins', type=int, nargs=1, default=[10],
+                        help='If this option is given alongside plots, sets the number of reaction coordinate bins for'
+                             'the sigmoid committor histogram. Production of the histogram will fail if any of the '
+                             'bins have zero samples in them, which is more likely for larger values of hist_bins. '
+                             'Default = 10')
 
     arguments = vars(parser.parse_args())  # Retrieves arguments as a dictionary object
 
