@@ -288,7 +288,7 @@ def main(settings, rescue_running=[]):
                 temp_settings.__dict__.pop('env')  # env attribute is not picklable
                 pickle.dump(temp_settings, open(settings.working_directory + '/settings.pkl', 'wb'), protocol=2)
             # Run resample
-            utilities.resample(settings, partial=False, full_cvs=settings.resample_full_cvs)
+            utilities.resample(settings, partial=False, full_cvs=settings.full_cvs)
             if settings.information_error_checking:     # update info_err.out if called for by settings
                 information_error.main()
             sys.exit()
@@ -333,7 +333,7 @@ def main(settings, rescue_running=[]):
                 pass
         if not settings.dont_dump:
             temp_settings = copy.deepcopy(settings)  # initialize temporary copy of settings to modify
-            temp_settings.__dict__.pop('env')  # env attribute is not picklable
+            temp_settings.__dict__.pop('env')  # env attribute is not picklable (update: maybe no longer true, but doesn't matter)
             pickle.dump(temp_settings, open(settings.working_directory + '/settings.pkl', 'wb'), protocol=2)
 
         # Build or load threads
@@ -363,7 +363,11 @@ def main(settings, rescue_running=[]):
 
     try:
         if settings.job_type == 'aimless_shooting' and len(os.sched_getaffinity(0)) > 1:
+            # Initialize Manager for shared data across processes; this is necessary because multiprocessing is being
+            # retrofitted to code designed for serial processing, but it works!
             manager = Manager()
+
+            # Setup Managed allthreads list
             managed_allthreads = []
             for thread in allthreads:
                 thread_dict = thread.__dict__
@@ -374,8 +378,18 @@ def main(settings, rescue_running=[]):
                 managed_thread.history.__dict__.update(thread_history_dict)
                 managed_allthreads.append(managed_thread)
             allthreads = manager.list(managed_allthreads)
+
+            # Setup Managed settings Namespace
+            settings_dict = settings.__dict__
+            managed_settings = manager.Namespace()
+            # Need to explicitly update every key because of how the Managed Namespace works.
+            # Calling exec is the best way to do this I could find. Updating managed_settings.__dict__ doesn't work.
+            for key in settings_dict.keys():
+                exec('managed_settings.' + key + ' = settings_dict[key]')
+
+            # Distribute processes among available core Pool
             with Pool(len(os.sched_getaffinity(0))) as p:
-                p.starmap(main_loop, zip(itertools.repeat(settings), itertools.repeat(allthreads), [[thread] for thread in allthreads]))
+                p.starmap(main_loop, zip(itertools.repeat(managed_settings), itertools.repeat(allthreads), [[thread] for thread in allthreads]))
         else:
             main_loop(settings, allthreads, running)
     except AttributeError:  # os.sched_getaffinity raises AttributeError on non-UNIX systems.
@@ -405,7 +419,7 @@ def main_loop(settings, allthreads, running):
                     if attempted_rescue == True:
                         interpreted.append(thread)
                     if termination_criterion:
-                        for thread in running:    # todo: should I replace this with something to finish up running jobs and just block submission of new ones?
+                        for thread in running:
                             for job_index in range(len(thread.current_type)):
                                 thread.cancel_job(job_index, settings)
                         running = []
@@ -417,13 +431,8 @@ def main_loop(settings, allthreads, running):
                                     if proc in [psutil.STATUS_RUNNING, psutil.STATUS_SLEEPING, psutil.STATUS_DISK_SLEEP]:
                                         proc_status = 'running'
                                         time.sleep(60)  # wait 1 minute before checking again
-                                    elif proc in [psutil.STATUS_ZOMBIE, psutil.STATUS_DEAD]:
-                                        proc_status = 'not_running'
                                     else:
-                                        warnings.warn(
-                                            'unexpected process state for information_error.py subprocess: ' + proc +
-                                            '\nSkipping information error checking at this step')
-                                        proc_status = 'error'
+                                        proc_status = 'not_running'
                                 except (psutil.NoSuchProcess, ProcessLookupError):
                                     proc_status = 'not_running'
                         break
@@ -445,7 +454,10 @@ def run_main():
         working_directory = sys.argv[2]
     except IndexError:
         working_directory = ''
-    settings = configure.configure(sys.argv[1], working_directory)
+    try:
+        settings = configure.configure(sys.argv[1], working_directory)
+    except IndexError:
+        raise RuntimeError('No configuration file specified. See documentation at atesa.readthedocs.io for details.')
     exit_message = main(settings)
     print(exit_message)
 
