@@ -16,16 +16,21 @@ import pickle
 import copy
 import subprocess
 import warnings
+import itertools
+from multiprocess import Pool
 from statsmodels.tsa import stattools
 
 def check_commit(filename, settings):
     """
     Check commitment of coordinate file to basins defined by settings.commit_fwd and settings.commit_bwd.
 
+    Raises a RuntimeError if the supplied file is not suitable for checking for commitment.
+
     Parameters
     ----------
     filename : str
-        Name of .rst7-formatted coordinate file to be checked
+        Name of coordinate or trajectory file to be checked. If the file has more than one frame, only the last frame
+        will be loaded.
     settings : argparse.Namespace
         Settings namespace object
 
@@ -39,7 +44,9 @@ def check_commit(filename, settings):
     # todo: consider adding support for angles and dihedrals
 
     try:
-        traj = pytraj.iterload(filename, settings.topology)
+        traj = pytraj.load(filename, settings.topology, frame_indices=[-1])
+        if traj.n_frames == 0:
+            raise RuntimeError('Attempted to check commitment for file: ' + filename + ' but it has no frames.')
     except ValueError as e:
         raise RuntimeError('Unable to load file: ' + filename + ' for checking commitment with the specified topology '
                            'file.\npytraj returned error: ' + str(e))
@@ -94,19 +101,21 @@ def get_cvs(filename, settings, reduce=False, frame=0):
     If reduce = True, the returned CVs will be reduced to between 0 and 1 based on the minimum and maximum values of
     that CV in as.out, which is assumed to exist at settings.as_out_file.
 
-    If frame is anything other than 0, it will be interpreted as a frame index and filename will be interpreted as a
-    trajectory file instead of an .rst7 coordinate file. This option is incompatible with settings.include_qdot = True.
+    If frame is > 0 or 'all', filename will be interpreted as a trajectory file instead of a .rst7 coordinate file.
+    This option is incompatible with settings.include_qdot = True.
 
     Parameters
     ----------
     filename : str
-        Name of .rst7-formatted coordinate file to be checked (or trajectory file if not frame == 0)
+        Name of .rst7-formatted coordinate file to be checked (or trajectory file if frame > 0 or frame == 'all')
     settings : argparse.Namespace
         Settings namespace object
     reduce : bool
         Boolean determining whether to reduce the CV values for use in evaluating an RC value that uses reduced values
-    frame : int
-        Frame of trajectory filename to use (1-indexed, negatives not valid, only used if not equal to 0)
+    frame : int or str
+        Frame of trajectory filename to use (1-indexed, negatives not valid, only used if not equal to 0); or, 'all'
+        returns the CVs for each frame of the input trajectory, separated by newlines. 'all' is incompatible with
+        settings.include_qdot = True
 
     Returns
     -------
@@ -160,21 +169,27 @@ def get_cvs(filename, settings, reduce=False, frame=0):
         # Returns a reduced value for a CV given an unreduced value and the index within as.out corresponding to that CV
         this_min = rc_minmax[0][local_index]
         this_max = rc_minmax[1][local_index]
+        if this_min == this_max:
+            return unreduced_value      # can't reduce when a CV only has a single value across rc_minmax
         return (float(unreduced_value) - this_min) / (this_max - this_min)
 
-    os.chdir(settings.working_directory)    # make sure we're in the working directory
+    if frame == 'all' and settings.include_qdot:
+        raise RuntimeError('utilities.get_cvs cannot be called with frame=all if settings.include_qdot == True')
+
+    if not os.getcwd() == settings.working_directory:
+        os.chdir(settings.working_directory)    # make sure we're in the working directory
 
     # define variables as they are expected to be interpreted in CV definitions (these are potentially invoked by eval)
     delete_traj_name = False  # so we don't delete the traj_name file later unless we created it below
-    if frame == 0:
-        traj = pytraj.iterload(filename, settings.topology)
-        mtraj = mdtraj.load(filename, top=settings.topology)
+    if frame in [0, 'all']:
+        full_traj = pytraj.iterload(filename, settings.topology)
+        full_mtraj = mdtraj.load(filename, top=settings.topology)
         traj_name = filename
     elif frame < 0:
         raise RuntimeError('frame must be >= 0')
     else:
-        traj = pytraj.iterload(filename, settings.topology, frame_slice=[(frame - 1, frame)])
-        mtraj = mdtraj.load_frame(filename, frame - 1, top=settings.topology)
+        full_traj = pytraj.iterload(filename, settings.topology, frame_slice=[(frame - 1, frame)])
+        full_mtraj = mdtraj.load_frame(filename, frame - 1, top=settings.topology)
         if True in ['traj_name' in cv for cv in settings.cvs]:  # if True, need .rst7 formatted file to operate on
             mdengine = factory.mdengine_factory(settings.md_engine)
             traj_name = mdengine.get_frame(filename, frame, settings)
@@ -197,39 +212,53 @@ def get_cvs(filename, settings, reduce=False, frame=0):
     output = ''
     values = []
     local_index = -1
-    for cv in settings.cvs:
-        local_index += 1
-        evaluation = eval(cv)       # evaluate the CV definition code (potentially using traj, mtraj, and/or traj_name)
-        if settings.include_qdot:   # want to save values for later
-            values.append(float(evaluation))
-        if reduce:                  # reduce values if necessary
-            evaluation = reduce_cv(evaluation, local_index, rc_minmax)
-        output += str(evaluation) + ' '
-    if settings.include_qdot and not settings.job_type == 'equilibrium_path_sampling':  # if True, then we want to include rate of change for every CV, too
-        # Strategy here is to write a new temporary .rst7 file by incrementing all the coordinate values by their
-        # corresponding velocity values, load it as a new iterload object, and then rerun our analysis on that.
-        incremented_filename = increment_coords()
-        traj = pytraj.iterload(incremented_filename, settings.topology)
-        mtraj = mdtraj.load(incremented_filename, top=settings.topology)
-        local_index = -1
+    sigfigs = '%.' + str(settings.sigfigs) + 'f'
+
+    if frame == 'all':
+        n_iter = full_traj.n_frames
+    else:
+        n_iter = 1
+
+    for iter in range(n_iter):  # iterate over all frames
+        # set traj and mtraj to only the desired frame; has no (important) effect if there's only one frame anyway
+        traj = full_traj[iter:iter+1:1]
+        mtraj = full_mtraj[iter]
         for cv in settings.cvs:
             local_index += 1
-            evaluation = eval(cv) - values[local_index]  # Subtract value 1/20.455 ps earlier from value of cv
-            if reduce:
-                try:
-                    evaluation = reduce_cv(evaluation, local_index + len(settings.cvs), rc_minmax)
-                except IndexError:
-                    raise RuntimeError('attempted to obtain a reduced value for the rate-of-change ("qdot") of CV' +
-                                       str(local_index) + ', but the corresponding column appears to be missing from '
-                                       'the aimless shooting output file: ' + settings.as_out_file + '. If this is the '
-                                       'wrong file, please specify the right one with the "as_out_file" option in the '
-                                       'configuration file. If this is the right file but it does not contain qdot '
-                                       'terms, please add "include_qdot = False" to the configuration file.')
-            output += str(evaluation) + ' '
-        os.remove(incremented_filename)     # clean up temporary file
+            evaluation = eval(cv)       # evaluate the CV definition code (potentially using traj, mtraj, and/or traj_name)
+            if settings.include_qdot:   # want to save values for later
+                values.append(float(evaluation))
+            if reduce:                  # reduce values if necessary
+                evaluation = reduce_cv(evaluation, local_index, rc_minmax)
+            output += sigfigs % float(evaluation) + ' '
+        if n_iter > 1:
+            output += '\n'
+        elif settings.include_qdot and not settings.job_type == 'equilibrium_path_sampling':  # if True, then we want to include rate of change for every CV, too
+            # Strategy here is to write a new temporary .rst7 file by incrementing all the coordinate values by their
+            # corresponding velocity values, load it as a new iterload object, and then rerun our analysis on that.
+            incremented_filename = increment_coords()
+            traj = pytraj.iterload(incremented_filename, settings.topology)
+            mtraj = mdtraj.load(incremented_filename, top=settings.topology)
+            local_index = -1
+            for cv in settings.cvs:
+                local_index += 1
+                evaluation = eval(cv) - values[local_index]  # Subtract value 1/20.455 ps earlier from value of cv
+                if reduce:
+                    try:
+                        evaluation = reduce_cv(evaluation, local_index + len(settings.cvs), rc_minmax)
+                    except IndexError:
+                        raise RuntimeError('attempted to obtain a reduced value for the rate-of-change ("qdot") of CV' +
+                                           str(local_index) + ', but the corresponding column appears to be missing from '
+                                           'the aimless shooting output file: ' + settings.as_out_file + '. If this is the '
+                                           'wrong file, please specify the right one with the "as_out_file" option in the '
+                                           'configuration file. If this is the right file but it does not contain qdot '
+                                           'terms, please add "include_qdot = False" to the configuration file.')
+                output += sigfigs % float(evaluation) + ' '
+            os.remove(incremented_filename)     # clean up temporary file
 
-    if output[-1] == ' ':
-        output = output[:-1]    # remove trailing space
+    while output[-1] in [' ', '\n']:
+        output = output[:-1]                # remove trailing space and/or newline on terminating line
+    output = output.replace(' \n', '\n')    # remove trailing spaces on non-terminating lines
 
     if delete_traj_name:
         os.remove(traj_name)
@@ -341,7 +370,7 @@ def resample(settings, partial=False, full_cvs=False):
 
     """
 
-    # todo: test this thoroughly using a dummy thread and a manual decorrelation time calculation using different software
+    # todo: test this more thoroughly using a dummy thread and a manual decorrelation time calculation using different software
 
     # This function is sometimes called from outside the working directory, so make sure we're there
     os.chdir(settings.working_directory)
@@ -488,19 +517,58 @@ def resample(settings, partial=False, full_cvs=False):
         open(settings.working_directory + '/as_full_cvs.out', 'w').close()
         temp_settings = copy.deepcopy(settings)
         temp_settings.include_qdot = False  # never want to include_qdot in this upcoming call to get_cvs
-        with open(settings.working_directory + '/as_full_cvs.out', 'a') as f:
-            for thread in allthreads:
-                for step_index in range(min([len(thread.history.prod_results), len(thread.history.prod_trajs)])):    # just in case one got an extra write in over the other
-                    if thread.history.prod_results[step_index] in [['fwd', 'bwd'], ['bwd', 'fwd']]:     # if step accepted
-                        for job_index in range(2):
-                            if os.path.exists(thread.history.prod_trajs[step_index][job_index]):
-                                for frame_index in range(pytraj.iterload(thread.history.prod_trajs[step_index][job_index], settings.topology).n_frames):
-                                    f.write(get_cvs(thread.history.prod_trajs[step_index][job_index], temp_settings, False, frame_index + 1) + '\n')
-                                    ## Deprecated code from before the frame argument was implemented in get_cvs
-                                    # frame_to_check = thread.get_frame(thread.history.prod_trajs[step_index][job_index], frame_index + 1, temp_settings)
-                                    # f.write(get_cvs(frame_to_check, temp_settings) + '\n')
-                                    # os.remove(frame_to_check)
+        try:
+            affinity = len(os.sched_getaffinity(0))
+        except AttributeError:  # os.sched_getaffinity raises AttributeError on non-UNIX systems.
+            affinity = 1
+        if affinity == 1:
+            with open(settings.working_directory + '/as_full_cvs.out', 'a') as f:
+                for thread in allthreads:
+                    for step_index in range(min([len(thread.history.prod_results), len(thread.history.prod_trajs)])):    # just in case one got an extra write in over the other
+                        if thread.history.prod_results[step_index] in [['fwd', 'bwd'], ['bwd', 'fwd']]:     # if step accepted
+                            for job_index in range(2):
+                                if os.path.exists(thread.history.prod_trajs[step_index][job_index]):
+                                    f.write(get_cvs(thread.history.prod_trajs[step_index][job_index], temp_settings, False, 'all') + '\n')
+        else:   # affinity > 1
+            # Map partial_full_cvs calls to available processes
+            with Pool(affinity) as p:
+                p.starmap(partial_full_cvs, zip(allthreads, ['partial_full_cvs_' + str(thread_index) + '.out' for thread_index in range(len(allthreads))], itertools.repeat(temp_settings)))
+            # Finally, combine the partial files into the full file
+            with open(settings.working_directory + '/as_full_cvs.out', 'w') as outfile:
+                for fname in ['partial_full_cvs_' + str(thread_index) + '.out' for thread_index in range(len(allthreads))]:
+                    with open(fname) as infile:
+                        for line in infile:
+                            if line:    # skip blank lines
+                                outfile.write(line)
+                    os.remove(fname)
 
+def partial_full_cvs(thread, filename, settings):
+    """
+    Write the full CVs list to the file given by filename for each accepted move in each thread in threads.
+
+    A helper function for parallelizing get_cvs (has to be defined at top-level for multiprocessing)
+
+    Parameters
+    ----------
+    thread : Thread
+        Thread object to evaluate
+    filename : str
+        Name of the file to write CVs to
+    settings : argparse.Namespace
+        Settings namespace object
+
+    Returns
+    -------
+    None
+
+    """
+    open(settings.working_directory + '/' + filename, 'w').close()
+    with open(settings.working_directory + '/' + filename, 'a') as f:
+        for step_index in range(min([len(thread.history.prod_results), len(thread.history.prod_trajs)])):  # just in case one got an extra write in over the other
+            if thread.history.prod_results[step_index] in [['fwd', 'bwd'], ['bwd', 'fwd']]:  # if step accepted
+                for job_index in range(2):
+                    if os.path.exists(thread.history.prod_trajs[step_index][job_index]):
+                        f.write(get_cvs(thread.history.prod_trajs[step_index][job_index], settings, False, 'all') + '\n')
 
 def interpret_cv(cv_index, settings):
     """
